@@ -21,7 +21,7 @@
  * Authors:
  *   Mattias Nordstrom <matta at ftlight net>
  *
- * $Id: mainwindow.cpp,v 1.14 2005/10/03 19:04:55 mnordstr Exp $
+ * $Id: mainwindow.cpp,v 1.18 2005/10/16 12:03:32 mnordstr Exp $
  *   This file provides the GUI.
  */
 
@@ -65,7 +65,7 @@ MainWindow::MainWindow()
 	
 	int i;
 	for (i=0; i<config->value("server/connections").toInt(); i++) {
-		downloaders.append(new Downloader(&nzblist, i, &file_lock, this));
+		downloaders.append(new Downloader(&nzblist, i, &file_lock, l, this));
 		d->setItem(i, 0, new QTableWidgetItem("Downloader #"+QString::number(i+1)));
 		d->setItem(i, 2, new QTableWidgetItem("0 kB/s"));
 		connect(this, SIGNAL(fullStop()), downloaders[i], SLOT(stop()));
@@ -79,6 +79,11 @@ MainWindow::MainWindow()
 	output = new Output(&nzblist, i+1, &file_lock, this);
 	connect(this, SIGNAL(processOutput()), output, SLOT(process()));
 	connect(this, SIGNAL(fullStop()), output, SLOT(stop()));
+
+	int drows = d->rowCount();
+	for (int row=0; row<drows; row++) {
+		d->resizeRowToContents(row);
+	}
 	
 	setWindowTitle(tr("nzb"));
 }
@@ -215,15 +220,6 @@ void MainWindow::readSettings()
 	move(pos);
 	split->restoreState(config->value("mainwindow/split").toByteArray());
 	
-	// Fix for situation when the default value isn't honored.
-	l->horizontalHeader()->resizeSection(0, 3);
-	l->horizontalHeader()->resizeSection(1, 3);
-	l->horizontalHeader()->resizeSection(2, 3);
-	l->horizontalHeader()->resizeSection(3, 3);
-	d->horizontalHeader()->resizeSection(0, 3);
-	d->horizontalHeader()->resizeSection(1, 3);
-	d->horizontalHeader()->resizeSection(2, 3);
-	
 	l->horizontalHeader()->resizeSection(0, config->value("mainwindow/listcol0width", 50).toInt());
 	l->horizontalHeader()->resizeSection(1, config->value("mainwindow/listcol1width", 50).toInt());
 	l->horizontalHeader()->resizeSection(2, config->value("mainwindow/listcol2width", 50).toInt());
@@ -231,6 +227,15 @@ void MainWindow::readSettings()
 	d->horizontalHeader()->resizeSection(0, config->value("mainwindow/dlistcol0width", 50).toInt());
 	d->horizontalHeader()->resizeSection(1, config->value("mainwindow/dlistcol1width", 50).toInt());
 	d->horizontalHeader()->resizeSection(2, config->value("mainwindow/dlistcol2width", 50).toInt());
+
+	// Fix for situation when the default value isn't honored.
+	if (l->columnWidth(0) == 0) l->horizontalHeader()->resizeSection(0, 50);
+	if (l->columnWidth(1) == 0) l->horizontalHeader()->resizeSection(1, 50);
+	if (l->columnWidth(2) == 0) l->horizontalHeader()->resizeSection(2, 50);
+	if (l->columnWidth(3) == 0) l->horizontalHeader()->resizeSection(3, 50);
+	if (d->columnWidth(0) == 0) d->horizontalHeader()->resizeSection(0, 50);
+	if (d->columnWidth(1) == 0) d->horizontalHeader()->resizeSection(1, 50);
+	if (d->columnWidth(2) == 0) d->horizontalHeader()->resizeSection(2, 50);
 }
 
 void MainWindow::writeSettings()
@@ -274,10 +279,15 @@ void MainWindow::populateList()
 			newItem_size = new QTableWidgetItem(QString::number(file_bytes)+" bytes");
 		}
 			
+		newItem->setCheckState(Qt::Checked);
+		
 		l->setItem(row, 0, newItem);
 		l->setItem(row, 1, newItem_prog);
 		l->setItem(row, 2, newItem_tot);
 		l->setItem(row, 3, newItem_size);
+
+		l->resizeRowToContents(row);
+
 		row++;
 	}
 	
@@ -404,12 +414,8 @@ void MainWindow::options()
 void MainWindow::downloadEvent(QString message, int row, int type)
 {
 	if (type == 0) {
-		//QTableWidgetItem *newtext = new QTableWidgetItem(message);
-		//d->setItem(row, 1, newtext);
 		d->model()->setData(d->model()->index(row, 1), message);
 	} else if (type == 2) {
-		//QTableWidgetItem *newcount = new QTableWidgetItem(QString::number((l->item(row, 1)->text()).toInt()+1));
-		//l->setItem(row, 1, newcount);
 		l->model()->setData(l->model()->index(row, 1), (l->item(row, 1)->text()).toInt()+1);
 		totalProgress->setValue(totalProgress->value() + 1);
 		
@@ -422,11 +428,9 @@ void MainWindow::downloadEvent(QString message, int row, int type)
 		emit processDecoder();
 		
 	} else if (type == 3) {
-		QTableWidgetItem *newtext = new QTableWidgetItem(message);
-		d->setItem(row, 1, newtext);
+		d->model()->setData(d->model()->index(row, 1), message);
 	} else if (type == 4) {
-		QTableWidgetItem *newtext = new QTableWidgetItem(message+" kB/s");
-		d->setItem(row, 2, newtext);
+		d->model()->setData(d->model()->index(row, 2), message+" kB/s");
 		
 		int total_speed = 0;
 		for (int i=0; i<downloaders.size(); i++) {
@@ -439,8 +443,7 @@ void MainWindow::downloadEvent(QString message, int row, int type)
 
 void MainWindow::decodeEvent(QString message, int row, int type)
 {
-	QTableWidgetItem *newtext = new QTableWidgetItem(message);
-	d->setItem(row, 1, newtext);
+	d->model()->setData(d->model()->index(row, 1), message);
 	
 	if (type == 1) {
 		emit processOutput();
